@@ -18,24 +18,42 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-# This seems to break rbx
-# require 'async/io/endpoint'
+require 'async/io/endpoint'
+require 'async/io/tcp_socket'
 
 RSpec.describe Async::IO::Endpoint do
 	include_context Async::RSpec::Reactor
 	
+	describe Async::IO::Endpoint.ssl('0.0.0.0', 5234, hostname: "lolcathost") do
+		it "should have hostname" do
+			expect(subject.hostname).to be == "lolcathost"
+		end
+	end
+	
 	describe Async::IO::Endpoint.tcp('0.0.0.0', 5234, reuse_port: true) do
 		it "should be a tcp binding" do
 			subject.bind do |server|
 				expect(server.local_address.socktype).to be == ::Socket::SOCK_STREAM
 			end
 		end
+		
+		it "should print nicely" do
+			expect(subject.to_s).to include('0.0.0.0', '5234')
+		end
+		
+		it "has options" do
+			expect(subject.options[:reuse_port]).to be true
+		end
+		
+		it "has hostname" do
+			expect(subject.hostname).to be == '0.0.0.0'
+		end
 	end
 	
 	describe Async::IO::SocketEndpoint.new(TCPServer.new('0.0.0.0', 1234)) do
 		it "should bind to given socket" do
 			subject.bind do |server|
-				expect(server.io).to be == subject.specification
+				expect(server).to be == subject.socket
 			end
 		end
 	end
